==> wordpress-0.0.2.tgz: package/gitignore/test.js <==
var wordpress = require( "../lib/wordpress" );

var client = wordpress.createClient({
	host: "wordpress.local",
	port: 80,
	// host: "localhost",
	// port: 2000,
	path: "/xmlrpc.php",
	username: "admin",
	password: "admin"
});

// client.createPost({
// 	title: "Pager New",
// 	content: "even moar page",
// 	type: "page",
// 	parent: 2,
// 	status: "publish"
// }, function() {
// 	console.log( arguments );
// });

// client.createPost({
// 	title: "Post with auto terms",
// 	content: "got terms?",
// 	terms_names: {
// 		post_tag: [ "foo", "bar" ]
// 	}
// }, function() {
// 	console.log( arguments );
// });

// client.editPost( 20, {
// 	title: "Up Page"
// }, function() {
// 	console.log( arguments );
// });

// client.deletePost( 20, function() {
// 	console.log( arguments );
// });

// client.getPost( 32, function() {
// 	// console.log( arguments );
// 	// console.log( arguments[1].terms );
// 	console.log( arguments[1].customFields );
// });

// client.editPost( 32, {
// 	termNames: {
// 		// post_tag: [ 4, 5 ],
// 		category: [ "myothercat" ],
// 	},
// 	customFields: [
// 		{
// 			id: "27"
// 			// key: "afoo",
// 			// value: "abar"
// 		}
// 	]
// }, function() {
// 	console.log( arguments );
// });

// client.getTaxonomy( "category", function( error, taxonomy ) {
// 	console.log( error );
// 	console.log( taxonomy );
// });

// client.getTaxonomies(function( error, taxonomies ) {
// 	// console.log( arguments );
// 	taxonomies.forEach(function( taxonomy ) {
// 		console.log( taxonomy.name );
// 	});
// });

// client.getTerm( "category", 6, function( error, term ) {
// 	console.log( error );
// 	console.log( term );
// });

// client.getTerms( "category",
// // {
// // 	hideEmpty: true
// // },
// function( error, categories ) {
// 	console.log( error );
// 	console.log( categories );
// });

// client.newTerm({
// 	name: "amazing term",
// 	taxonomy: "category"
// }, function( error, data ) {
// 	console.log( error );
// 	console.log( data );
// });

// client.editTerm( 8, {
// 	taxonomy: "category",
// 	slug: "derp"
// }, function( error, data ) {
// 	console.log( error );
// 	console.log( data );
// });

// client.deleteTerm( "category", 8, function( error, data ) {
// 	console.log( error );
// 	console.log( data );
// });

client.getPosts({
	type: "page",
	orderby: "post_date",
	order: "ASC"
}, function() {
	console.log( arguments );
});

return;













var wordpress = require( "../lib/wordpress" );

var client = wordpress.createClient({
	host: "localhost",
	port: 8889,
	database: "wordpress_plugins_jquery_com",
	user: "jqueryplugins",
	password: "plugins"
});



//client.createPost({
//	content: "<p>This is a newer test</p>",
//	title: "Field Maps + Helpers!",
//	date: new Date( "March 6, 2008 9:00" ),
//	status: "draft"
//}, function() {
//	console.log( arguments );
//	client.end();
//});

//client.updatePost( 20, {
//	contentFiltered: "wat?"
//}, function() {
//	console.log( arguments );
//	client.end();
//});

//client.removePost( 15, function() {
//	console.log( arguments );
//	client.end();
//});

//client.findPosts({
//	title: "FIRST!"
//}, function() {
//	console.log( arguments );
//	client.end();
//});



//client.setMeta( 14, "test2", "new other value", function() {
//	console.log( arguments );
//	client.end();
//});

//client.getMeta( 15, function() {
//	console.log( arguments );
//	client.end();
//});

//client.removeMeta( 14, "test2", function() {
//	console.log( arguments );
//	client.end();
//});


// client.addTag( 3, "wattup", function() {
// 	console.log( arguments );
// 	client.end();
// });

//client.createCategory( "Amazo Cat", "amazonian", function() {
//	console.log( arguments );
//	client.end();
//});
//client.addCategory( 3, "puffy2", function() {
//	console.log( arguments );
//	client.end();
//});

// client.getCategoriesAll(function() {
// 	console.log( arguments );
// 	client.end();
// });

==> wordpress-0.0.5.tgz: package/gitignore/test.js <==
var wordpress = require( "../lib/wordpress" );

var client = wordpress.createClient({
	host: "wordpress.local",
	port: 80,
	host: "localhost",
	port: 2000,
	// host: "stage.api.jquery.com",
	// port: 80,
	path: "/xmlrpc.php",
	username: "admin",
	password: "admin"
});

client.newPost({
	content: "öö"
}, function() {});

// client.newPost({
// 	title: "Pager New",
// 	content: "even moar page",
// 	type: "page",
// 	parent: 2,
// 	status: "publish"
// }, function() {
// 	console.log( arguments );
// });

// client.newPost({
// 	title: "Post with auto terms",
// 	content: "got terms?",
// 	terms_names: {
// 		post_tag: [ "foo", "bar" ]
// 	}
// }, function() {
// 	console.log( arguments );
// });

// client.editPost( 20, {
// 	title: "Up Page"
// }, function() {
// 	console.log( arguments );
// });

// client.deletePost( 20, function() {
// 	console.log( arguments );
// });

// client.getPost( 2,
// 	[ "customFields", "name" ],
// function( error, post ) {
// 	console.log( error );
// 	console.log( post );
// });

// client.editPost( 32, {
// 	termNames: {
// 		// post_tag: [ 4, 5 ],
// 		category: [ "myothercat" ],
// 	},
// 	customFields: [
// 		{
// 			id: "27"
// 			// key: "afoo",
// 			// value: "abar"
// 		}
// 	]
// }, function() {
// 	console.log( arguments );
// });

// client.getTaxonomy( "category", function( error, taxonomy ) {
// 	console.log( error );
// 	console.log( taxonomy );
// });

// client.getTaxonomies(function( error, taxonomies ) {
// 	// console.log( arguments );
// 	taxonomies.forEach(function( taxonomy ) {
// 		console.log( taxonomy.name );
// 	});
// });

// client.getTerm( "category", 6, function( error, term ) {
// 	console.log( error );
// 	console.log( term );
// });

// client.getTerms( "category",
// // {
// // 	hideEmpty: true
// // },
// function( error, categories ) {
// 	console.log( error );
// 	console.log( categories );
// });

// client.newTerm({
// 	name: "amazing term",
// 	taxonomy: "category"
// }, function( error, data ) {
// 	console.log( error );
// 	console.log( data );
// });

// client.editTerm( 8, {
// 	taxonomy: "category",
// 	slug: "derp"
// }, function( error, data ) {
// 	console.log( error );
// 	console.log( data );
// });

// client.deleteTerm( "category", 8, function( error, data ) {
// 	console.log( error );
// 	console.log( data );
// });

// client.getPosts({
// 	type: "page",
// 	orderby: "post_date",
// 	order: "ASC"
// },
// [ "content", "name" ],
// function() {
// 	console.log( arguments );
// });

// client.getPostType( "page", function( error, postType ) {
// 	console.log( error );
// 	console.log( postType );
// });

// client.getPosts( "any", function() {
// 	console.log( arguments );
// });

// client.getPostTypes(function( error, postTypes ) {
// 	console.log( error );
// 	console.log( postTypes );
// });


// client.call( "system.listMethods", function() {
// 	console.log( arguments );
// });

// client.call( "gw.getPostPaths", function() {
// 	console.log( arguments );
// });
